@@ -22,7 +22,9 @@ from django.utils.translation import ugettext as _
 
 from Theophrastus.models import Newsletter
 from Theophrastus.statistics.admin import NewsletterStatisticsAdmin
-from Theophrastus.integration.models import App, Group, GroupMappingTable
+from Theophrastus.integration.models import (
+    App, Group, GroupMappingTable, AppMailingList, AppNewsletter
+)
 from Theophrastus.integration.service import IntegrationService
 from Theophrastus.integration.forms import AppAdminForm, GroupMappingTableForm
 from Theophrastus.integration.forms import NewsletterIntegrationForm
@@ -61,7 +63,7 @@ class NewsletterIntegrationChangeList(ChangeList):
             return [q['id'] for q in _group.newsletters.values('id')]
         return []
 
-    def getQuerySet(self, original=False):
+    def getQuerySet(self, request='', original=False):
 
         ids = self.getIdsByGroup()
 
@@ -71,14 +73,15 @@ class NewsletterIntegrationChangeList(ChangeList):
             else:
                 return Newsletter.objects.exclude(id__in=self.getAllAppIds())
 
-        queryset = super(NewsletterIntegrationChangeList, self).get_query_set()
+        queryset = super(
+            NewsletterIntegrationChangeList, self).get_queryset(request)
         if ids:
             return queryset.filter(id__in=ids)
         else:
             return queryset.exclude(id__in=self.getAllAppIds())
 
-    def get_query_set(self):
-        return self.getQuerySet()
+    def get_queryset(self, request):
+        return self.getQuerySet(request=request)
 
 class NewsletterIntegrationAdmin(NewsletterStatisticsAdmin):
 
@@ -104,11 +107,11 @@ class AppChangeList(ChangeList):
         self._user = request.user
         super(AppChangeList, self).__init__(request, *args, **kwargs)
 
-    def get_query_set(self):
+    def get_queryset(self, request):
 
         if self._user.is_authenticated() and self._user.is_staff:
             user = self._user
-            queryset = super(AppChangeList, self).get_query_set()
+            queryset = super(AppChangeList, self).get_queryset(request)
             queryset = queryset.filter(user=user)
             return queryset
         else:
@@ -209,7 +212,7 @@ class GroupChangeList(ChangeList):
 
         return []
 
-    def getQuerySet(self, original=False):
+    def getQuerySet(self, request='', original=False):
         apps = self.getApps()
 
         if original:
@@ -218,27 +221,27 @@ class GroupChangeList(ChangeList):
                 queryset = queryset.filter(id__in=apps)
             return queryset
 
-        queryset = super(GroupChangeList, self).get_query_set()
+        queryset = super(GroupChangeList, self).get_queryset(request)
         if apps:
-#            if 'app' in self.params:
-#                del self.params['app']
-#            _queryset = None
-#            try:
-#                _app = integrationSrv.getApp(id=self._app, user=self._user)
-#                _queryset = _app.groups.all()
-#            except:
-#                return Group.objects.none()
+            if 'app' in self.params:
+               del self.params['app']
+            _queryset = None
+            try:
+                _app = integrationSrv.getApp(id=self._app, user=self._user)
+                _queryset = _app.groups.all()
+            except:
+                return Group.objects.none()
 
-            #if self.params:
-                #ids = [q['id'] for q in _queryset.values('id')]
-                #queryset = super(GroupChangeList, self).get_query_set()
+            if self.params:
+                ids = [q['id'] for q in _queryset.values('id')]
+                queryset = super(GroupChangeList, self).get_queryset(request)
             return queryset.filter(id__in=apps)
         else:
             return queryset.filter(id__in=self.findIdsByUser())
 
-    def get_query_set(self):
+    def get_queryset(self, request):
 
-        return self.getQuerySet()
+        return self.getQuerySet(request=request)
 
 class GroupAdmin(admin.ModelAdmin):
 
@@ -325,16 +328,17 @@ admin.site.register(GroupMappingTable, GroupMappingTableAdmin)
 
 from Theophrastus.models import MailingList
 from emencia.django.newsletter.admin import MailingListAdmin
+# from Theophrastus.cloud.admin import MailingListAdmin
 
 class MailingListChangeList(ChangeList):
     def __init__(self, request, *args, **kwargs):
         super(MailingListChangeList, self).__init__(request, *args, **kwargs)
 
-    def getQuerySet(self, original=False):
+    def getQuerySet(self, request='', original=False):
         if original:
             queryset = MailingList.objects.all()
         else:
-            queryset = super(MailingListChangeList, self).get_query_set()
+            queryset = super(MailingListChangeList, self).get_queryset(request)
 
         ids = []
         for _a in integrationSrv.findAllApps():
@@ -342,15 +346,62 @@ class MailingListChangeList(ChangeList):
             ids.extend([g['id'] for g in groups])
         return queryset.exclude(newsletter__group__id__in=ids)
 
-    def get_query_set(self):
-        return self.getQuerySet()
+    def get_queryset(self, request):
+        return self.getQuerySet(request=request)
 
 class MailingListIntegrationAdmin(MailingListAdmin):
     def get_changelist(self, request, **kwargs):
         """
-        Returns the ChangeList class for use on the changelist page.
+	        Returns the ChangeList class for use on the changelist page.
         """
         return MailingListChangeList
 
+class AppMailingListFilter(admin.SimpleListFilter):
+    # Human-readable title which will be displayed in the
+    # right admin sidebar just above the filter options.
+    title = _('App')
+
+    # Parameter for the filter that will be used in the URL query.
+    parameter_name = 'decade'
+
+    def lookups(self, request, model_admin):
+        """
+        Returns a list of tuples. The first element in each
+        tuple is the coded value for the option that will
+        appear in the URL query. The second element is the
+        human-readable name for the option that will appear
+        in the right sidebar.
+        """
+        appTuple = ()
+        appMaillingList = AppMailingList.objects.all()
+        for ele in appMaillingList:
+            appName = ele.app.name
+            appId = ele.app.id
+            appTuple += (appId, appName)
+
+        return appTuple
+
+    def queryset(self, request, queryset):
+        """
+        Returns the filtered queryset based on the value
+        provided in the query string and retrievable via
+        `self.value()`.
+        """
+        # Compare the requested value (either '80s' or '90s')
+        # to decide how to filter the queryset.
+        appId = self.value
+        appMailingList = AppMailingList.objects.filter(appId=appId)
+        mailingListIdList = appMailingList.values_list('mailingList', flat=True)
+        return MailingList.objects.filter(id__in=MailingList)
+        
+
+# class MailingListIntegrationAdmin(MailingListAdmin):
+#     list_filter = ('name',)
+#     def get_changelist(self, request, **kwargs):
+#         """
+#         Returns the ChangeList class for use on the changelist page.
+#         """
+#         return MailingListChangeList
+
 admin.site.unregister(MailingList)
 admin.site.register(MailingList, MailingListIntegrationAdmin)
