@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: admin.py 10662 2017-12-19 10:11:52Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,12 +11,14 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2017-12-19 18:11:52 +0800 (Tue, 19 Dec 2017) $
+# $Revision: 10662 $
 
 from django.contrib import admin
 
+from emencia.django.newsletter.models import Newsletter
+
 from Theophrastus.newsletter_extension.models import Header, Footer
 from Theophrastus.newsletter_extension.forms import HeaderTinyMCEForm
 from Theophrastus.newsletter_extension.forms import FooterTinyMCEForm
