@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 9579 2016-03-09 01:43:46Z Judy $
+# $Id: models.py 10662 2017-12-19 10:11:52Z David $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,15 +11,19 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Judy $
-# $Date: 2016-03-09 09:43:46 +0800 (三, 09  3 2016) $
-# $Revision: 9579 $
+# $Author: David $
+# $Date: 2017-12-19 18:11:52 +0800 (Tue, 19 Dec 2017) $
+# $Revision: 10662 $
 
+from Theophrastus.models import Newsletter, Contact
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
 
 class Header(models.Model):
 
+    title = models.CharField(
+        _('title'), max_length=255, blank=True, null=True
+    )
     content = models.TextField(
         _('Header content'), blank=True, null=True,
         help_text=_('Custom your header content.'))
@@ -33,6 +37,9 @@ class Header(models.Model):
 
 class Footer(models.Model):
 
+    title = models.CharField(
+        _('title'), max_length=255, blank=True, null=True
+    )
     content = models.TextField(
         _('Footer content'), blank=True, null=True,
         help_text=_('Custom your footer content.'))
@@ -43,3 +50,11 @@ class Footer(models.Model):
     class Meta:
         verbose_name = _('Footer')
         verbose_name_plural = _('Footers')
+
+class ErrorMessage(models.Model):
+
+    message =  models.CharField(max_length=2048, blank=True, null=True)
+
+    newsletter = models.ForeignKey(Newsletter, verbose_name=_('newsletter'))
+
+    contact = models.ForeignKey(Contact, verbose_name=_('contact'))
\ No newline at end of file
